@@ -1,22 +1,8 @@
-/****************************************************************************
-Copyright 2016  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2016 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-****************************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef KWAYLAND_CLIENT_POINTERCONSTRAINTS_H
 #define KWAYLAND_CLIENT_POINTERCONSTRAINTS_H
 
@@ -34,7 +20,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class LockedPointer;
 class Surface;
@@ -77,7 +62,7 @@ public:
      * Registry::createPointerConstraints.
      **/
     explicit PointerConstraints(QObject *parent = nullptr);
-    virtual ~PointerConstraints();
+    ~PointerConstraints() override;
 
     /**
      * Setup this PointerConstraints to manage the @p pointerconstraints.
@@ -139,7 +124,7 @@ public:
          * A persistent pointer constraint may again reactivate once it has
          * been deactivated.
          **/
-        Persistent
+        Persistent,
     };
 
     /**
@@ -212,8 +197,8 @@ public:
      **/
     ConfinedPointer *confinePointer(Surface *surface, Pointer *pointer, Region *region, LifeTime lifetime, QObject *parent = nullptr);
 
-    operator zwp_pointer_constraints_v1*();
-    operator zwp_pointer_constraints_v1*() const;
+    operator zwp_pointer_constraints_v1 *();
+    operator zwp_pointer_constraints_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -262,7 +247,7 @@ class KWAYLANDCLIENT_EXPORT LockedPointer : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~LockedPointer();
+    ~LockedPointer() override;
 
     /**
      * Setup this LockedPointer to manage the @p lockedpointer.
@@ -328,8 +313,8 @@ public:
      **/
     void setRegion(Region *region);
 
-    operator zwp_locked_pointer_v1*();
-    operator zwp_locked_pointer_v1*() const;
+    operator zwp_locked_pointer_v1 *();
+    operator zwp_locked_pointer_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -380,7 +365,7 @@ class KWAYLANDCLIENT_EXPORT ConfinedPointer : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~ConfinedPointer();
+    ~ConfinedPointer() override;
 
     /**
      * Setup this ConfinedPointer to manage the @p confinedpointer.
@@ -407,10 +392,8 @@ public:
      * that the instance can be deleted or set up to a new zwp_confined_pointer_v1 interface
      * once there is a new connection available.
      *
-     * It is suggested to connect this method to ConnectionThread::connectionDied:
-     * @code
-     * connect(connection, &ConnectionThread::connectionDied, confinedpointer, &ConfinedPointer::destroy);
-     * @endcode
+     * This method is automatically invoked when the Registry which created this
+     * PointerConstraints gets destroyed.
      *
      * @see release
      **/
@@ -438,8 +421,8 @@ public:
      **/
     void setRegion(Region *region);
 
-    operator zwp_confined_pointer_v1*();
-    operator zwp_confined_pointer_v1*() const;
+    operator zwp_confined_pointer_v1 *();
+    operator zwp_confined_pointer_v1 *() const;
 
 Q_SIGNALS:
     /**
@@ -466,7 +449,6 @@ private:
     QScopedPointer<Private> d;
 };
 
-
 }
 }
 
